diff --git a/services/overall/learning-materials.md b/services/overall/learning-materials.md
index f74034d34123d42c4fa2c4a5333bd9db5e0cc974..54180572b548c68cba1b2514ea7637ab610c0b46 100644
--- a/services/overall/learning-materials.md
+++ b/services/overall/learning-materials.md
@@ -25,14 +25,15 @@ If you find issues or would like to contribute, feel free to take a look at the
 
 ### General
 
-| Topic                                  | Materials        | Repository                               |
-|----------------------------------------|------------------|------------------------------------------|
-| Research Software Publication          | (In preparation) | [Repository][sw-publication-repo]        |
-| Container Virtualization in Science    | (In preparation) | [Repository][containers-in-science-repo] |
-| Event Management with Indico           | (In preparation) | [Repository][indico-repo]                |
-| Getting started with Markdown Flavours | (In preparation) | [Repository][markdown-repo]              |
+| Topic                                  | Materials                   | Repository                               |
+| -------------------                    | -----------                 | -----------                              |
+| Research Software Publication          | (In preparation)            | [Repository][sw-publication-repo]        |
+| Container Virtualization in Science    | (In preparation)            | [Repository][containers-in-science-repo] |
+| Event Management with Indico           | [Material][indico-material] | [Repository][indico-repo]                |
+| Getting started with Markdown Flavours | (In preparation)            | [Repository][markdown-repo]              |
 
 [containers-in-science-repo]: https://gitlab.hzdr.de/hifis/software/education/hifis-workshops/workshop-using-containers-in-science
+[indico-material]: {{ "workshop-materials/tool-indico/" | relative_url }}
 [indico-repo]: https://gitlab.hzdr.de/hifis/software/education/hifis-workshops/workshop-event-management-with-indico
 [markdown-repo]: https://gitlab.hzdr.de/hifis/software/education/hifis-workshops/workshop-getting-started-with-markdown-flavors
 [sw-publication-repo]: https://gitlab.hzdr.de/hifis/software/education/hifis-workshops/foundations-of-research-software-publication
diff --git a/fetch_external_content.sh b/fetch_external_content.sh
index 955ef9268370352e9340a2d482948ae1ca201cc3..d5706a8156c13877897138b572790ec893d00719 100755
--- a/fetch_external_content.sh
+++ b/fetch_external_content.sh
@@ -17,41 +17,50 @@ function include_mkdocs(){
   popd
 }
 
-# ----------
+#---------------#
 
-# 1. Get content for education/training materials.
+#== 1. Get content for education/training materials. ==#
+#-- Workshop Python - object oriented programming
 include_mkdocs \
   "https://gitlab.hzdr.de/hifis/software/education/hifis-workshops/workshop-oop-in-python/-/jobs/artifacts/main/download?job=pages" \
   "workshop-materials/python-oop/"
 
+#-- Workshop Python - pandas
 include_mkdocs \
   "https://gitlab.hzdr.de/hifis/software/education/hifis-workshops/workshop-pandas/-/jobs/artifacts/main/download?job=pages" \
   "workshop-materials/python-pandas/"
 
+#-- Workshop Python - matplotlib
 include_mkdocs \
   "https://gitlab.hzdr.de/hifis/software/education/hifis-workshops/workshop-matplotlib/-/jobs/artifacts/main/download?job=pages" \
   "workshop-materials/python-matplotlib/"
 
+#-- Workshop Tool - Gitlab CI
 include_mkdocs \
   "https://gitlab.hzdr.de/hifis/software/education/hifis-workshops/gitlab-ci/workshop-materials/-/jobs/artifacts/main/download?job=pages" \
   "workshop-materials/gitlab-ci/"
 
-# 2. Get HIFIS Intro letter
+#-- Workshop Tool - Indico
+include_mkdocs \
+  "https://gitlab.hzdr.de/hifis/software/education/hifis-workshops/workshop-event-management-with-indico/-/jobs/artifacts/main/download?job=pages" \
+  "workshop-materials/tool-indico/"
+
+#== 2. Get HIFIS Intro letter ==#
 wget https://gitlab.hzdr.de/hifis/overall/communication/hifis-news/-/jobs/artifacts/main/raw/build/2022-03_overview_de.pdf?job=build -O media/HIFIS_overview_2022_03_de.pdf
 wget https://gitlab.hzdr.de/hifis/overall/communication/hifis-news/-/jobs/artifacts/main/raw/build/2022-03_overview_en.pdf?job=build -O media/HIFIS_overview_2022_03_en.pdf
 
-# 3. Get HIFIS Teaser Video
+#== 3. Get HIFIS Teaser Video ==#
 wget https://gitlab.hzdr.de/hifis/overall/communication/hifis-teaser-video/-/jobs/artifacts/main/raw/video/video_full.mp4?job=video_build -O assets/videos/video_full.mp4
 
-# 4. Get Administrative and Technical Documentation
+#== 4. Get Administrative and Technical Documentation ==#
 # tbd
 
-# 5. Get content for consulting-handbook.
+#== 5. Get content for consulting-handbook. ==#
 include_mkdocs \
   "https://gitlab.hzdr.de/hifis/software/consulting/consulting-handbook/-/jobs/artifacts/main/download?job=pages" \
   "consulting-handbook/"
 
-
-# 6. Not sure if this will persists, but for the time being: update newsletter project to newest master always.
+#== 6. Not sure if this will persists, but for the time being: update newsletter project to newest master always. ==#
 git submodule sync
 git submodule update --remote submodules/hifis-newsletter/
+
diff --git a/workshop-materials/tool-indico/.gitkeep b/workshop-materials/tool-indico/.gitkeep
new file mode 100644
index 0000000000000000000000000000000000000000..e69de29bb2d1d6434b8b29ae775ad8c2e48c5391